@@ -3,13 +3,14 @@ Main interface for iot1click-projects service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iot1click_projects import (
+    from mypy_boto3_iot1click_projects import (
         Client,
         IoT1ClickProjectsClient,
         ListPlacementsPaginator,
         ListProjectsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,12 +19,12 @@ Usage::
 
     list_placements_paginator: ListPlacementsPaginator = client.get_paginator("list_placements")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
+    ```
 """
-from mypy_boto3_iot1click_projects.client import (
-    IoT1ClickProjectsClient as Client,
-    IoT1ClickProjectsClient,
-)
+from mypy_boto3_iot1click_projects.client import IoT1ClickProjectsClient
 from mypy_boto3_iot1click_projects.paginator import ListPlacementsPaginator, ListProjectsPaginator
 
+Client = IoT1ClickProjectsClient
+
 
 __all__ = ("Client", "IoT1ClickProjectsClient", "ListPlacementsPaginator", "ListProjectsPaginator")
